# SPDX-License-Identifier: Apache-2.0

from __future__ import absolute_import
from __future__ import division
from __future__ import print_function
from __future__ import unicode_literals

import numpy as np  # type: ignore


def abs(input):  # type: (np.ndarray) -> np.ndarray
    return np.abs(input)
