



pip check
IF %ERRORLEVEL% NEQ 0 exit /B 1
check-model --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
check-node --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
backend-test-tools --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
